@@ -1,7 +1,7 @@
 // synthv1.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -52,14 +52,17 @@ public:
 
 		DCO1_SHAPE1 = 0,
 		DCO1_WIDTH1,
+		DCO1_BANDL1,
 		DCO1_SHAPE2,
 		DCO1_WIDTH2,
+		DCO1_BANDL2,
 		DCO1_BALANCE,
 		DCO1_DETUNE,
 		DCO1_PHASE,
 		DCO1_OCTAVE,
 		DCO1_TUNING,
 		DCO1_GLIDE,
+		DCO1_ENVTIME,
 		DCF1_CUTOFF,
 		DCF1_RESO,
 		DCF1_TYPE,
@@ -100,14 +103,17 @@ public:
 
 		DCO2_SHAPE1,
 		DCO2_WIDTH1,
+		DCO2_BANDL1,
 		DCO2_SHAPE2,
 		DCO2_WIDTH2,
+		DCO2_BANDL2,
 		DCO2_BALANCE,
 		DCO2_DETUNE,
 		DCO2_PHASE,
 		DCO2_OCTAVE,
 		DCO2_TUNING,
 		DCO2_GLIDE,
+		DCO2_ENVTIME,
 		DCF2_CUTOFF,
 		DCF2_RESO,
 		DCF2_TYPE,
@@ -166,6 +172,11 @@ public:
 		DEL1_BPM,
 		DEL1_BPMSYNC,
 		DEL1_BPMHOST,
+		REV1_WET,
+		REV1_ROOM,
+		REV1_DAMP,
+		REV1_FEEDB,
+		REV1_WIDTH,
 		DYN1_COMPRESS,
 		DYN1_LIMITER,
 
