@@ -197,16 +197,16 @@ int synthv1_jack::process ( jack_nframes_t nframes )
 			::jack_port_get_buffer(m_audio_outs[k], nframes));
 	}
 
-	const float *bpm_sync = synthv1::paramPort(synthv1::DEL1_BPMSYNC);
-	if (bpm_sync && *bpm_sync > 0.0f) {
-		float *bpm_port = synthv1::paramPort(synthv1::DEL1_BPM);
-		if (bpm_port) {
+	const float *bpmsync = paramPort(synthv1::DEL1_BPMSYNC);
+	if (bpmsync && *bpmsync > 0.0f) {
+		float *bpmhost = paramPort(synthv1::DEL1_BPMHOST);
+		if (bpmhost) {
 			jack_position_t pos;
 			jack_transport_query(m_client, &pos);
 			if (pos.valid & JackPositionBBT) {
 				const float bpm = float(pos.beats_per_minute);
-				if (::fabs(*bpm_port - bpm) > 0.01f)
-					*bpm_port = bpm;
+				if (::fabs(*bpmhost - bpm) > 0.01f)
+					*bpmhost = bpm;
 			}
 		}
 	}
@@ -299,11 +299,11 @@ void synthv1_jack::open ( const char *client_id )
 
 	char port_name[32];
 	for (uint16_t k = 0; k < nchannels; ++k) {
-		::snprintf(port_name, sizeof(port_name), "in_%d", k);
+		::snprintf(port_name, sizeof(port_name), "in_%d", k + 1);
 		m_audio_ins[k] = ::jack_port_register(m_client,
 			port_name, JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput, 0);
 		m_ins[k] = NULL;
-		::snprintf(port_name, sizeof(port_name), "out_%d", k);
+		::snprintf(port_name, sizeof(port_name), "out_%d", k + 1);
 		m_audio_outs[k] = ::jack_port_register(m_client,
 			port_name, JACK_DEFAULT_AUDIO_TYPE, JackPortIsOutput, 0);
 		m_outs[k] = NULL;
