@@ -137,6 +137,15 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	const QString& sAuto = tr("Auto");
 	m_ui.Del1BpmKnob->setSpecialValueText(sAuto);
 
+	// Wave integer widths.
+	m_ui.Dco1Width1Knob->setDecimals(0);
+	m_ui.Dco1Width2Knob->setDecimals(0);
+	m_ui.Dco2Width1Knob->setDecimals(0);
+	m_ui.Dco2Width2Knob->setDecimals(0);
+
+	m_ui.Lfo1WidthKnob->setDecimals(0);
+	m_ui.Lfo2WidthKnob->setDecimals(0);
+
 	// DCO octave limits.
 	m_ui.Dco1OctaveKnob->setMinimum(-4.0f);
 	m_ui.Dco1OctaveKnob->setMaximum(+4.0f);
@@ -223,6 +232,7 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Del1BpmKnob->setScale(1.0f);
 	m_ui.Del1BpmKnob->setMinimum(3.6f);
 	m_ui.Del1BpmKnob->setMaximum(360.0f);
+	m_ui.Del1BpmKnob->setSingleStep(1.0f);
 
 	// Reverb (stereo-)width limits.
 	m_ui.Rev1WidthKnob->setMinimum(-1.0f);
@@ -919,7 +929,7 @@ void synthv1widget::updateParamValues (void)
 			fValue = *pfParamPort;
 		setParamValue(index, fValue, true);
 		updateParam(index, fValue);
-		updateParamEx(index, fValue);
+	//	updateParamEx(index, fValue);
 		m_params_ab[index] = fValue;
 	}
 }
@@ -1116,10 +1126,8 @@ void synthv1widget::bpmSyncChanged (void)
 	if (pSynth) {
 		float *pBpmSync = pSynth->paramPort(synthv1::DEL1_BPMSYNC);
 		if (pBpmSync) {
-			const bool bBpmSync0
-				= (*pBpmSync > 0.0f);
-			const bool bBpmSync1
-				= (m_ui.Del1BpmKnob->minimum() >= m_ui.Del1BpmKnob->value());
+			const bool bBpmSync0 = (*pBpmSync > 0.0f);
+			const bool bBpmSync1 = m_ui.Del1BpmKnob->isSpecialValue();
 			if ((bBpmSync1 && !bBpmSync0) || (!bBpmSync1 && bBpmSync0))
 				*pBpmSync = (bBpmSync1 ? 1.0f : 0.0f);
 		}
