@@ -28,8 +28,6 @@
 
 #include "synthv1.h"
 
-#include <QHash>
-
 
 //-------------------------------------------------------------------------
 // synthv1widget - decl.
@@ -85,6 +83,8 @@ protected slots:
 	void bpmSyncChanged();
 
 	// Menu actions.
+	void helpUseNativeDialogs(bool bOn);
+
 	void helpAbout();
 	void helpAboutQt();
 
@@ -96,6 +96,9 @@ protected:
 	// Reset swap params A/B group.
 	void resetSwapParams();
 
+	// Initialize all param/knob values.
+	void updateParamValues();
+
 	// Reset all param/knob default values.
 	void resetParamValues();
 	void resetParamKnobs();
