@@ -1,7 +1,7 @@
 // synthv1widget_config.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -61,6 +61,12 @@ void synthv1widget_config::load (void)
 	sPreset = QSettings::value("/Preset").toString();
 	sPresetDir = QSettings::value("/PresetDir").toString();
 	QSettings::endGroup();
+
+	QSettings::beginGroup("/Dialogs");
+	bUseNativeDialogs = QSettings::value("/UseNativeDialogs", true).toBool();
+	// Run-time special non-persistent options.
+	bDontUseNativeDialogs = !bUseNativeDialogs;
+	QSettings::endGroup();
 }
 
 
@@ -75,6 +81,10 @@ void synthv1widget_config::save (void)
 	QSettings::setValue("/PresetDir", sPresetDir);
 	QSettings::endGroup();
 
+	QSettings::beginGroup("/Dialogs");
+	QSettings::setValue("/UseNativeDialogs", bUseNativeDialogs);
+	QSettings::endGroup();
+
 	QSettings::sync();
 }
 
