@@ -39,44 +39,15 @@ class synthv1_nsm;
 
 class synthv1widget_jack : public synthv1widget
 {
-	Q_OBJECT
-
 public:
 
 	// Constructor.
 	synthv1widget_jack(synthv1_jack *pSynth);
 
-	// Destructor.
-	~synthv1widget_jack();
-
-#ifdef CONFIG_JACK_SESSION
-
-	// JACK session self-notification.
-	void notifySessionEvent(void *pvSessionArg);
-
-signals:
-
-	// JACK session notify event.
-	void sessionNotify(void *);
-
-protected slots:
-
-	// JACK session event handler.
-	void sessionEvent(void *pvSessionArg);
-
-#endif	// CONFIG_JACK_SESSION
-
 #ifdef CONFIG_NSM
-
-protected slots:
-
-	// NSM callback slots.
-	void openSession();
-	void saveSession();
-
-	void hideSession();
-	void showSession();
-
+	// NSM client accessors.
+	void setNsmClient(synthv1_nsm *pNsmClient);
+	synthv1_nsm *nsmClient() const;
 #endif	// CONFIG_NSM
 
 protected:
@@ -94,11 +65,9 @@ protected:
 	void closeEvent(QCloseEvent *pCloseEvent);
 
 #ifdef CONFIG_NSM
-
 	// Optional GUI handlers.
 	void showEvent(QShowEvent *pShowEvent);
 	void hideEvent(QHideEvent *pHideEvent);
-
 #endif	// CONFIG_NSM
 
 private:
@@ -108,7 +77,6 @@ private:
 
 #ifdef CONFIG_NSM
 	synthv1_nsm *m_pNsmClient;
-	bool m_bNsmDirty;
 #endif
 };
 
